@@ -86,7 +86,7 @@ class ImageModelTraining:
         for epoch in range(self.num_epochs):
             print(f"Epoch {epoch + 1}/{self.num_epochs}")
             train_loss = self.train_model_epoch(model, self.train_loader, criterion, optimizer)
-            evaluate_accuracy = self.evaluate_model(model=model, data_loader=self.val_loader)
+            evaluate_accuracy = self.evaluate_model(model=model, data_loader=self.val_loader, device=self.device)
             print(f"Train Loss: {train_loss:.4f} - Evaluate Accuracy: {evaluate_accuracy:.4f}")
         return train_loss, evaluate_accuracy
 
@@ -116,13 +116,15 @@ class ImageModelTraining:
         return epoch_loss
 
     @staticmethod
-    def evaluate_model(model, data_loader):
+    def evaluate_model(model, data_loader, device):
         correct = 0
         total = 0
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
-                outputs = model(images)
+                images, labels = labels.to(device).float(), labels.to(device)
+
+                outputs = model(images).to(device)
                 _, predicted = torch.max(outputs.data, 1)
                 total += labels.size(0)
                 correct += (predicted == labels).sum().item()
@@ -131,13 +133,13 @@ class ImageModelTraining:
         return accuracy
 
     @staticmethod
-    def get_eval_prediction(model, data_loader, num_classes):
+    def get_eval_prediction(model, data_loader, device, num_classes):
         # Get the predictions for the eval set
         eval_preds = []
         with torch.no_grad():
             for data in data_loader:
                 images, labels = data
-                outputs = model(images)
+                outputs = model(images).to(device)
                 for i in range(outputs.size(0)):  # iterate over batch size
                     output = outputs[i]
                     _, predicted = torch.max(output, 0)
