@@ -17,7 +17,6 @@ class ImagesData:
         self.images_to_show = np.transpose(images, (0, 2, 3, 1))
 
     def split(self):
-        print("Splitting Data to Train and Evaluation Set")
         assert 0 <= self.validation_prop < 0.8, "validation proportion should be in range (0, 0.8)"
         num_val = int(self.validation_prop * len(self.images))
         indices = np.random.permutation(len(self.images))
@@ -96,7 +95,7 @@ class ImageModel:
         self.dropout = dropout
         if self.optimizer_params is None:
             self.optimizer_params = {"lr": 0.01, 'weight_decay': 0.0001}
-        self.network_parameters = optimizer_params.copy()
+        self.network_parameters = self.optimizer_params.copy()
         self.network_parameters["_model_name"] = self.network_name
         self.network_parameters["_num_epochs"] = self.num_epochs
         self.network_parameters["_batch_size"] = self.batch_size
